@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 our $VERSION;
-$VERSION = '0.01';
+$VERSION = '0.02';
 
 use Net::DNS qw(:DEFAULT);
 use base qw(Exporter Net::DNS);
@@ -19,13 +19,13 @@ Net::DNS::Multicast - Multicast extension to Net::DNS
 
     use Net::DNS::Multicast;
     my $resolver = Net::DNS::Resolver->new();
-    my $response = $resolver( 'host.local.', 'A' );
+    my $response = $resolver( 'host.local.', 'AAAA' );
 
 =head1 DESCRIPTION
 
 Net::DNS::Multicast is installed as an extension to an existing Net::DNS
 installation providing packages to support simple IP multicast queries
-as specified in RFC6762(5.1).
+as described in RFC6762(5.1).
 
 The multicast feature is made available by replacing Net::DNS by
 Net::DNS::Multicast in the use declaration.
@@ -47,6 +47,17 @@ sub unicast_response {
 }
 
 
+require Net::DNS::RR;
+
+package Net::DNS::RR;
+
+sub cache_flush {
+	my ( $self, @value ) = @_;				# uncoverable pod
+	for (@value) { $self->{qclass} |= ( $_ << 15 ) }
+	return $self->{qclass} >> 15;
+}
+
+
 require Net::DNS::Resolver;
 
 package Net::DNS::Resolver;
@@ -55,15 +66,7 @@ my $defaults = __PACKAGE__->_defaults;
 $defaults->{multicast_group} = [qw(FF02::FB 224.0.0.251)];
 $defaults->{multicast_port}  = 5353;
 
-my $NAME_REGEX = q/\.(local|254\.169\.in-addr\.arpa|[89ab]\.e\.f\.ip6\.arpa)$/;
-
-sub string {
-	my $self = shift;
-	return join( '', $self->SUPER::string, <<END );
-;; multicast_group	@{$self->{multicast_group}}
-;; multicast_ port	$self->{multicast_port}
-END
-}
+my $NAME_REGEX = q/\.(local|254\.169\.in-addr\.arpa|[89AB]\.E\.F\.ip6\.arpa)$/;
 
 sub send {
 	my ( $self, @argument ) = @_;
@@ -77,7 +80,6 @@ sub send {
 		$self->nameservers( @{$self->{multicast_group}} );
 		$self->port( $self->{multicast_port} );
 		$self->retrans(3);
-		$q->unicast_response(1);
 		return $self->_send_udp( $packet, $packet->data );
 	}
 
@@ -102,6 +104,14 @@ sub bgsend {
 	return $self->SUPER::bgsend($packet);
 }
 
+sub string {
+	my $self = shift;
+	return join( '', $self->SUPER::string, <<END );
+;; multicast_group	@{$self->{multicast_group}}
+;; multicast_ port	$self->{multicast_port}
+END
+}
+
 
 1;
 __END__
